Crate calico

Crate calico 

calico

calico is a parser and data model for the iCalendar format.

As of v0.3.0, calico supports end-to-end parsing of iCalendar objects including all standard component types (VEVENT, VTODO, VJOURNAL, VFREEBUSY, VTIMEZONE, VALARM) and RFC 9073 components (PARTICIPANT, VLOCATION, VRESOURCE).

RFC Support

Modules

model
The iCalendar object model.
parser
A winnow-based RFC 5545 parser implementation.
serializer
iCalendar serialization (RFC 5545 text format).

Macros

date
Constructs a Date from input of the form yyyy;MM;dd. Panics if the date is invalid.
text
Constructs a Text value from a string literal.
time
Constructs a Time from input of the form hh;mm;ss. Panics if the time is invalid.
utc_offset
Constructs a UtcOffset from input of the form +/-h;m(;s)?.